@@ -23,7 +23,7 @@
 #'  ----
 #'
 #'  section *text* with [a link](https://ropensci.org/)
-#'  
+#'
 #'  :::
 #' ")
 #' x <- xml2::read_xml(commonmark::markdown_xml(md))
@@ -32,8 +32,13 @@
 #' res
 #' xml2::xml_text(res)
 #' xml2::xml_find_all(res, ".//descendant-or-self::md:*", ns = ns)
-find_between <- function(body, ns, pattern = "md:paragraph[md:text[starts-with(text(), ':::')]]", include = FALSE) {
-  after  <- "following-sibling::"
+find_between <- function(
+  body,
+  ns,
+  pattern = "md:paragraph[md:text[starts-with(text(), ':::')]]",
+  include = FALSE
+) {
+  after <- "following-sibling::"
   before <- "preceding-sibling::"
   after_first_pattern <- glue::glue("{after}{pattern}")
   before_last_pattern <- glue::glue("{before}md:*[{before}{pattern}]")
