@@ -13,12 +13,11 @@ stylesheet <- function() {
 
 is_stylesheet <- function(stylesheet) {
   inherits(stylesheet, "xml_document") &&
-    length(xml2::xml_name(stylesheet)) == 1L    &&
+    length(xml2::xml_name(stylesheet)) == 1L &&
     xml2::xml_name(stylesheet) == "stylesheet"
 }
 
 read_stylesheet <- function(stylesheet_path) {
-
   # if the stylesheet already is an XML stylesheet, just return.
   if (is_stylesheet(stylesheet_path)) {
     return(stylesheet_path)
@@ -32,7 +31,10 @@ read_stylesheet <- function(stylesheet_path) {
     stop("'stylesheet_path' must be a path to an XSL stylesheet", call. = FALSE)
   }
   if (!file.exists(stylesheet_path)) {
-    stop(glue::glue("The file '{stylesheet_path}' does not exist."), call. = FALSE)
+    stop(
+      glue::glue("The file '{stylesheet_path}' does not exist."),
+      call. = FALSE
+    )
   }
   out <- xml2::read_xml(stylesheet_path)
   if (is_stylesheet(out)) {
@@ -40,5 +42,4 @@ read_stylesheet <- function(stylesheet_path) {
   } else {
     stop(glue::glue("'{stylesheet_path}' is not a valid stylesheet"))
   }
-
 }
