@@ -1,5 +1,4 @@
 test_that("to_md works without a file", {
-
   path <- system.file("extdata", "table.md", package = "tinkr")
   stys <- system.file("stylesheets", "xml2md_gfm.xsl", package = "tinkr")
   stys <- xml2::read_xml(stys)
@@ -11,53 +10,63 @@ test_that("to_md works without a file", {
   expect_length(res, 2)
   f <- textConnection(res)
 
-  fin  <- trimws(readLines(path, 3))
+  fin <- trimws(readLines(path, 3))
   fout <- trimws(readLines(f, 3))
   expect_equal(fin, fout)
   expect_match(res[[2]], "aaaaaaaaaa")
-
 })
 
 test_that("to_md fails if the stylesheet is not correct", {
-
-  tmp  <- withr::local_tempfile(fileext = ".xml")
+  tmp <- withr::local_tempfile(fileext = ".xml")
   path <- system.file("extdata", "table.md", package = "tinkr")
   yaml_xml_list <- to_xml(path)
   xml2::write_xml(yaml_xml_list$body, tmp)
   # NULL for stylesheet
-  expect_error(to_md(yaml_xml_list, stylesheet_path = NULL),
-    "'stylesheet_path' must be a path to an XSL stylesheet")
+  expect_error(
+    to_md(yaml_xml_list, stylesheet_path = NULL),
+    "'stylesheet_path' must be a path to an XSL stylesheet"
+  )
   # NA for stylesheet
-  expect_error(to_md(yaml_xml_list, stylesheet_path = NA),
-    "'stylesheet_path' must be a path to an XSL stylesheet")
+  expect_error(
+    to_md(yaml_xml_list, stylesheet_path = NA),
+    "'stylesheet_path' must be a path to an XSL stylesheet"
+  )
   # multi-element vector
-  expect_error(to_md(yaml_xml_list, stylesheet_path = letters),
-    "'stylesheet_path' must be a path to an XSL stylesheet")
+  expect_error(
+    to_md(yaml_xml_list, stylesheet_path = letters),
+    "'stylesheet_path' must be a path to an XSL stylesheet"
+  )
   # zero-element vector
-  expect_error(to_md(yaml_xml_list, stylesheet_path = character(0)),
-    "'stylesheet_path' must be a path to an XSL stylesheet")
+  expect_error(
+    to_md(yaml_xml_list, stylesheet_path = character(0)),
+    "'stylesheet_path' must be a path to an XSL stylesheet"
+  )
   # xml document that is not a stylesheet
-  expect_error(to_md(yaml_xml_list, stylesheet_path = tmp),
-    "'*.xml' is not a valid stylesheet")
+  expect_error(
+    to_md(yaml_xml_list, stylesheet_path = tmp),
+    "'*.xml' is not a valid stylesheet"
+  )
   # file that doesn't exist
-  expect_error(to_md(yaml_xml_list, stylesheet_path = "path/to/stylesheet.xsl"),
-    "The file 'path/to/stylesheet.xsl' does not exist.")
+  expect_error(
+    to_md(yaml_xml_list, stylesheet_path = "path/to/stylesheet.xsl"),
+    "The file 'path/to/stylesheet.xsl' does not exist."
+  )
   # xml object
-  expect_error(to_md(yaml_xml_list, stylesheet_path = yaml_xml_list$body),
-    "'stylesheet_path' must be a path to an XSL stylesheet")
-
+  expect_error(
+    to_md(yaml_xml_list, stylesheet_path = yaml_xml_list$body),
+    "'stylesheet_path' must be a path to an XSL stylesheet"
+  )
 })
 
 test_that("to_md works", {
   tmpdir <- withr::local_tempdir("newdir")
-  newmd  <- withr::local_file(file.path(tmpdir, "to_md-works.md"))
+  newmd <- withr::local_file(file.path(tmpdir, "to_md-works.md"))
   path <- system.file("extdata", "example1.md", package = "tinkr")
 
   yaml_xml_list <- to_xml(path)
   # transform level 3 headers into level 1 headers
   yaml_xml_list$body %>%
-    xml2::xml_find_all(xpath = './/d1:heading[@level="3"]',
-                       xml2::xml_ns(.)) %>%
+    xml2::xml_find_all(xpath = './/d1:heading[@level="3"]', xml2::xml_ns(.)) %>%
     xml2::xml_set_attr("level", 1)
 
   # save back and have a look
@@ -87,8 +96,7 @@ test_that("to_md works for Rmd", {
   yaml_xml_list <- to_xml(path, sourcepos = TRUE)
   body <- yaml_xml_list$body
   blocks <- yaml_xml_list$body %>%
-    xml2::xml_find_all(xpath = './/d1:code_block',
-                       xml2::xml_ns(.))
+    xml2::xml_find_all(xpath = './/d1:code_block', xml2::xml_ns(.))
 
   # Two non-evaluated blocks
   lang_attr <- xml2::xml_attr(blocks, "language")
@@ -133,7 +141,6 @@ test_that("to_md does not break tables", {
 })
 
 
-
 test_that("code chunks can be inserted on round trip", {
   tmpdir <- withr::local_tempdir("newdir")
   path <- system.file("extdata", "example2.Rmd", package = "tinkr")
@@ -167,18 +174,15 @@ test_that("code chunks can be inserted on round trip", {
 })
 
 test_that("links that start lines are not escaped", {
-
   expected <- "## Dataset\n\nThe data used:\n[data](https://example.com)\n"
   math <- commonmark::markdown_xml(expected)
   txt <- xml2::read_xml(math)
   protxt <- protect_inline_math(txt, md_ns())
   actual <- to_md(list(yaml = NULL, body = protxt))
   expect_equal(actual, expected)
-
 })
 
 test_that("to_md_vec() returns a vector of the same length as the nodelist", {
-
   path <- system.file("extdata", "example1.md", package = "tinkr")
   y <- tinkr::yarn$new(path, sourcepos = TRUE)
   items <- xml2::xml_find_all(y$body, ".//md:item", tinkr::md_ns())
@@ -225,3 +229,66 @@ test_that("(#59) Bare links are not transformed to markdown links", {
   expect_identical(expected, md)
 })
 
+test_that("list subitems keep their 3 spaces (ordered)", {
+  input <- c(
+    "1. My list item",
+    "   - First sub-item",
+    "   - Second sub-item",
+    ""
+  )
+  tmp <- withr::local_tempfile()
+  writeLines(input, tmp)
+  xml <- to_xml(tmp)
+  md <- to_md(xml)
+  md <- strsplit(md, split = "\n")
+  expect_snapshot(md)
+})
+
+test_that("list subitems keep their 2 spaces (unordered)", {
+  input <- c(
+    "- My list item",
+    "   - First sub-item",
+    "   - Second sub-item",
+    ""
+  )
+  tmp <- withr::local_tempfile()
+  writeLines(input, tmp)
+  xml <- to_xml(tmp)
+  md <- to_md(xml)
+  md <- strsplit(md, split = "\n")
+  expect_snapshot(md)
+})
+
+
+test_that("list subitems keep empty line", {
+  input <- c(
+    "- My list item",
+    "",
+    "   - First sub-item",
+    "   - Second sub-item",
+    ""
+  )
+  tmp <- withr::local_tempfile()
+  writeLines(input, tmp)
+  xml <- to_xml(tmp)
+  md <- to_md(xml)
+  md <- strsplit(md, split = "\n")
+  expect_snapshot(md)
+})
+
+
+test_that("list subitems keep empty line", {
+  input <- c(
+    "1. My list item",
+    "",
+    "   - First sub-item",
+    "   - Second sub-item",
+    ""
+  )
+  tmp <- withr::local_tempfile()
+  writeLines(input, tmp)
+  xml <- to_xml(tmp)
+  md <- to_md(xml)
+  md <- strsplit(md, split = "\n")
+  expect_snapshot(md)
+})
