@@ -24,12 +24,10 @@ test_that("to_xml works for Rmd", {
   expect_s3_class(post_list[[2]], "xml_document")
 
   blocks <- post_list[[2]] %>%
-    xml2::xml_find_all(xpath = './/d1:code_block',
-                       xml2::xml_ns(.)) %>%
+    xml2::xml_find_all(xpath = './/d1:code_block', xml2::xml_ns(.)) %>%
     .[xml2::xml_has_attr(., "language")]
 
   expect_equal(length(blocks), 4)
-
 })
 
 
@@ -46,7 +44,6 @@ test_that("to_xml can parse markdown with special control characters", {
 })
 
 
-
 test_that("to_xml will not convert numeric options to character", {
   txt <- "```{r txt, fig.width=4.2, fig.height=4.2, out.width='100%', purl = TRUE}\n#code\n```"
   con <- textConnection(txt)
@@ -62,7 +59,6 @@ test_that("to_xml will not convert numeric options to character", {
 
 
 test_that("to_xml will not convert chunk options as r objects to character", {
-
   txt <- "```{r txt, R.options = list(width = 100), eval = eval_param}\n#code\n```"
   con <- textConnection(txt)
   code <- xml2::xml_find_first(to_xml(con)$body, "d1:code_block")
@@ -70,11 +66,9 @@ test_that("to_xml will not convert chunk options as r objects to character", {
   expect_equal(attrs[["name"]], "txt")
   expect_equal(attrs[["R.options"]], "list(width = 100)")
   expect_equal(attrs[["eval"]], "eval_param")
-
 })
 
 test_that("to_xml will respect logicals for custom chunk options", {
-
   txt <- "```{r txt, coffee = TRUE, tea = FALSE, fun = 'pizza+icecream'}\n#code\n```"
   con <- textConnection(txt)
   code <- xml2::xml_find_first(to_xml(con)$body, "d1:code_block")
@@ -83,16 +77,13 @@ test_that("to_xml will respect logicals for custom chunk options", {
   expect_equal(attrs[["coffee"]], "TRUE")
   expect_equal(attrs[["tea"]], "FALSE")
   expect_equal(attrs[["fun"]], shQuote("pizza+icecream", type = "cmd"))
-
 })
 
 test_that("to_xml works with text connection", {
-
   path <- system.file("extdata", "example2.Rmd", package = "tinkr")
-  txt  <- readLines(path)
-  con  <- textConnection(txt)
+  txt <- readLines(path)
+  con <- textConnection(txt)
   expect_equal(to_xml(path)$frontmatter, to_xml(con)$frontmatter)
-
 })
 
 test_that("to_xml works with sourcepos", {
@@ -117,7 +108,10 @@ test_that("to_xml works with sourcepos for Rmd", {
   first_block <- xml2::xml_find_first(post_list[[2]], ".//d1:code_block")
 
   expect_match(xml2::xml_attr(first_block, "space"), "preserve")
-  expect_match(xml2::xml_attr(first_block, "sourcepos"), "^\\d+?:\\d+?-\\d+?:\\d+$")
+  expect_match(
+    xml2::xml_attr(first_block, "sourcepos"),
+    "^\\d+?:\\d+?-\\d+?:\\d+$"
+  )
   expect_match(xml2::xml_attr(first_block, "language"), "r")
   expect_match(xml2::xml_attr(first_block, "name"), "setup")
   expect_match(xml2::xml_attr(first_block, "include"), "FALSE")
